==> fastybird-ws-server-plugin-0.2.1.tar.gz: fastybird-ws-server-plugin-0.2.1/README.md <==
# FastyBird WS server plugin

[![Build Status](https://badgen.net/github/checks/FastyBird/ws-server-plugin/master?cache=300&style=flat-square)](https://github.com/FastyBird/ws-server-plugin/actions)
[![Licence](https://badgen.net/github/license/FastyBird/ws-server-plugin?cache=300&style=flat-square)](https://github.com/FastyBird/ws-server-plugin/blob/master/LICENSE.md)
[![Code coverage](https://badgen.net/coveralls/c/github/FastyBird/ws-server-plugin?cache=300&style=flat-square)](https://coveralls.io/r/FastyBird/ws-server-plugin)

![PHP](https://badgen.net/packagist/php/FastyBird/ws-server-plugin?cache=300&style=flat-square)
[![PHP latest stable](https://badgen.net/packagist/v/FastyBird/ws-server-plugin/latest?cache=300&style=flat-square)](https://packagist.org/packages/FastyBird/ws-server-plugin)
[![PHP downloads total](https://badgen.net/packagist/dt/FastyBird/ws-server-plugin?cache=300&style=flat-square)](https://packagist.org/packages/FastyBird/ws-server-plugin)
[![PHPStan](https://img.shields.io/badge/phpstan-enabled-brightgreen.svg?style=flat-square)](https://github.com/phpstan/phpstan)

![Python](https://badgen.net/pypi/python/fastybird-ws-server-plugin?cache=300&style=flat-square)
[![Python latest stable](https://badgen.net/pypi/v/fastybird-ws-server-plugin?cache=300&style=flat-square)](https://pypi.org/project/fastybird-ws-server-plugin/)
[![Python downloads month](https://img.shields.io/pypi/dm/fastybird-ws-server-plugin?cache=300&style=flat-square)](https://pypi.org/project/fastybird-ws-server-plugin/)
[![Black](https://img.shields.io/badge/black-enabled-brightgreen.svg?style=flat-square)](https://github.com/psf/black)

## What is FastyBird WS server plugin?

This is a combined plugin for [Nette framework](https://nette.org) and [Python](https://www.python.org) which is implementing [WAMPv1](https://wamp-proto.org) server based on [iPbulikuj WAMP server](https://github.com/ipublikuj/websockets-wamp) extension for [FastyBird](https://www.fastybird.com) IoT services

## Installation

### PHP based project:

The best way to install **fastybird/ws-server-plugin** is using [Composer](http://getcomposer.org/):

```sh
$ composer require fastybird/ws-server-plugin
```

### Python based project:

The best way to install **fastybird-redisdb-storage-plugin** is using [Pip](https://pip.pypa.io/en/stable/):

```sh
$ pip install fastybird-ws-server-plugin
```

## Documentation

Learn how to connect & call RPC messages in [documentation](https://github.com/FastyBird/ws-server-plugin/blob/master/.docs/en/index.md).

***
Homepage [https://www.fastybird.com](https://www.fastybird.com) and repository [https://github.com/FastyBird/ws-server-plugin](https://github.com/FastyBird/ws-server-plugin).

==> fastybird-ws-server-plugin-0.11.0.tar.gz: fastybird-ws-server-plugin-0.11.0/README.md <==
# FastyBird WS server plugin

[![Build Status](https://badgen.net/github/checks/FastyBird/ws-server-plugin/master?cache=300&style=flat-square)](https://github.com/FastyBird/ws-server-plugin/actions)
[![Licence](https://badgen.net/github/license/FastyBird/ws-server-plugin?cache=300&style=flat-square)](https://github.com/FastyBird/ws-server-plugin/blob/master/LICENSE.md)
[![Code coverage](https://badgen.net/coveralls/c/github/FastyBird/ws-server-plugin?cache=300&style=flat-square)](https://coveralls.io/r/FastyBird/ws-server-plugin)

![PHP](https://badgen.net/packagist/php/FastyBird/ws-server-plugin?cache=300&style=flat-square)
[![PHP latest stable](https://badgen.net/packagist/v/FastyBird/ws-server-plugin/latest?cache=300&style=flat-square)](https://packagist.org/packages/FastyBird/ws-server-plugin)
[![PHP downloads total](https://badgen.net/packagist/dt/FastyBird/ws-server-plugin?cache=300&style=flat-square)](https://packagist.org/packages/FastyBird/ws-server-plugin)
[![PHPStan](https://img.shields.io/badge/phpstan-enabled-brightgreen.svg?style=flat-square)](https://github.com/phpstan/phpstan)

![Python](https://badgen.net/pypi/python/fastybird-ws-server-plugin?cache=300&style=flat-square)
[![Python latest stable](https://badgen.net/pypi/v/fastybird-ws-server-plugin?cache=300&style=flat-square)](https://pypi.org/project/fastybird-ws-server-plugin/)
[![Python downloads month](https://img.shields.io/pypi/dm/fastybird-ws-server-plugin?cache=300&style=flat-square)](https://pypi.org/project/fastybird-ws-server-plugin/)
[![Black](https://img.shields.io/badge/black-enabled-brightgreen.svg?style=flat-square)](https://github.com/psf/black)
[![MyPy](https://img.shields.io/badge/mypy-enabled-brightgreen.svg?style=flat-square)](http://mypy-lang.org)

## What is FastyBird WS server plugin?

This is a combined plugin for [Nette framework](https://nette.org) and [Python](https://www.python.org) which is
implementing [WAMPv1](https://wamp-proto.org) server based
on [iPbulikuj WAMP server](https://github.com/ipublikuj/websockets-wamp) extension
for [FastyBird](https://www.fastybird.com) IoT services

## Installation

### PHP based project:

The best way to install **fastybird/ws-server-plugin** is using [Composer](http://getcomposer.org/):

```sh
$ composer require fastybird/ws-server-plugin
```

### Python based project:

The best way to install **fastybird-redisdb-storage-plugin** is using [Pip](https://pip.pypa.io/en/stable/):

```sh
$ pip install fastybird-ws-server-plugin
```

## Documentation

Learn how to connect & call RPC messages
in [documentation](https://github.com/FastyBird/ws-server-plugin/blob/master/.docs/en/index.md).

***
Homepage [https://www.fastybird.com](https://www.fastybird.com) and
repository [https://github.com/FastyBird/ws-server-plugin](https://github.com/FastyBird/ws-server-plugin).
